==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/FrontDoorManagedRuleOverrideArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ActionType
import com.pulumi.azurenative.network.kotlin.enums.ManagedRuleEnabledState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines a managed rule group override setting.
 * @property action Describes the override action to be applied when rule matches.
 * @property enabledState Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
 * @property exclusions Describes the exclusions that are applied to this specific rule.
 * @property ruleId Identifier for the managed rule.
 */
public data class FrontDoorManagedRuleOverrideArgs(
    public val action: Output<Either<String, ActionType>>? = null,
    public val enabledState: Output<Either<String, ManagedRuleEnabledState>>? = null,
    public val exclusions: Output<List<ManagedRuleExclusionArgs>>? = null,
    public val ruleId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs =
        com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .enabledState(
                enabledState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .exclusions(
                exclusions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .ruleId(ruleId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FrontDoorManagedRuleOverrideArgs].
 */
@PulumiTagMarker
public class FrontDoorManagedRuleOverrideArgsBuilder internal constructor() {
    private var action: Output<Either<String, ActionType>>? = null

    private var enabledState: Output<Either<String, ManagedRuleEnabledState>>? = null

    private var exclusions: Output<List<ManagedRuleExclusionArgs>>? = null

    private var ruleId: Output<String>? = null

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("qfuuunxppbdkbffj")
    public suspend fun action(`value`: Output<Either<String, ActionType>>) {
        this.action = value
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("mydendrabouhsfhv")
    public suspend fun enabledState(`value`: Output<Either<String, ManagedRuleEnabledState>>) {
        this.enabledState = value
    }

    /**
     * @param value Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("fosjcxwwkqafekno")
    public suspend fun exclusions(`value`: Output<List<ManagedRuleExclusionArgs>>) {
        this.exclusions = value
    }

    @JvmName("ecralcngqtxypjaw")
    public suspend fun exclusions(vararg values: Output<ManagedRuleExclusionArgs>) {
        this.exclusions = Output.all(values.asList())
    }

    /**
     * @param values Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("yrvvpxpqsmxhmlor")
    public suspend fun exclusions(values: List<Output<ManagedRuleExclusionArgs>>) {
        this.exclusions = Output.all(values)
    }

    /**
     * @param value Identifier for the managed rule.
     */
    @JvmName("nokdujfuuojikbyx")
    public suspend fun ruleId(`value`: Output<String>) {
        this.ruleId = value
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("noqknkrdltolumjc")
    public suspend fun action(`value`: Either<String, ActionType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("qwsmivcfbisuovyu")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("rrqabhxshfjbmkvu")
    public fun action(`value`: ActionType) {
        val toBeMapped = Either.ofRight<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("rkrrtvhfeytdfoyl")
    public suspend fun enabledState(`value`: Either<String, ManagedRuleEnabledState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("utcjoacysohlfyhd")
    public fun enabledState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ManagedRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("lfeebtoogtkpqmfx")
    public fun enabledState(`value`: ManagedRuleEnabledState) {
        val toBeMapped = Either.ofRight<String, ManagedRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("xakroxmxvthwjglo")
    public suspend fun exclusions(`value`: List<ManagedRuleExclusionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param argument Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("ykqkxjkpiuufiuhb")
    public suspend
    fun exclusions(argument: List<suspend ManagedRuleExclusionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ManagedRuleExclusionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.exclusions = mapped
    }

    /**
     * @param argument Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("qidfsatlotkbmxpf")
    public suspend fun exclusions(
        vararg
        argument: suspend ManagedRuleExclusionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ManagedRuleExclusionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.exclusions = mapped
    }

    /**
     * @param argument Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("evckaimtnivmlyph")
    public suspend fun exclusions(argument: suspend ManagedRuleExclusionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ManagedRuleExclusionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.exclusions = mapped
    }

    /**
     * @param values Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("wkofmkgckqmrlpol")
    public suspend fun exclusions(vararg values: ManagedRuleExclusionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param value Identifier for the managed rule.
     */
    @JvmName("xyphvqtrmdolpxcr")
    public suspend fun ruleId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleId = mapped
    }

    internal fun build(): FrontDoorManagedRuleOverrideArgs = FrontDoorManagedRuleOverrideArgs(
        action = action,
        enabledState = enabledState,
        exclusions = exclusions,
        ruleId = ruleId ?: throw PulumiNullFieldException("ruleId"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/FrontDoorManagedRuleOverrideArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ActionType
import com.pulumi.azurenative.network.kotlin.enums.ManagedRuleEnabledState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Defines a managed rule group override setting.
 * @property action Describes the override action to be applied when rule matches.
 * @property enabledState Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
 * @property exclusions Describes the exclusions that are applied to this specific rule.
 * @property ruleId Identifier for the managed rule.
 */
public data class FrontDoorManagedRuleOverrideArgs(
    public val action: Output<Either<String, ActionType>>? = null,
    public val enabledState: Output<Either<String, ManagedRuleEnabledState>>? = null,
    public val exclusions: Output<List<ManagedRuleExclusionArgs>>? = null,
    public val ruleId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs =
        com.pulumi.azurenative.network.inputs.FrontDoorManagedRuleOverrideArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .enabledState(
                enabledState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .exclusions(
                exclusions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .ruleId(ruleId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FrontDoorManagedRuleOverrideArgs].
 */
@PulumiTagMarker
public class FrontDoorManagedRuleOverrideArgsBuilder internal constructor() {
    private var action: Output<Either<String, ActionType>>? = null

    private var enabledState: Output<Either<String, ManagedRuleEnabledState>>? = null

    private var exclusions: Output<List<ManagedRuleExclusionArgs>>? = null

    private var ruleId: Output<String>? = null

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("lnkenqcwafpggpng")
    public suspend fun action(`value`: Output<Either<String, ActionType>>) {
        this.action = value
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("khhofifudlxmxays")
    public suspend fun enabledState(`value`: Output<Either<String, ManagedRuleEnabledState>>) {
        this.enabledState = value
    }

    /**
     * @param value Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("nbkmcgutahhvhbwq")
    public suspend fun exclusions(`value`: Output<List<ManagedRuleExclusionArgs>>) {
        this.exclusions = value
    }

    @JvmName("trpafrsmolncfjva")
    public suspend fun exclusions(vararg values: Output<ManagedRuleExclusionArgs>) {
        this.exclusions = Output.all(values.asList())
    }

    /**
     * @param values Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("dshvjmwyvefgibph")
    public suspend fun exclusions(values: List<Output<ManagedRuleExclusionArgs>>) {
        this.exclusions = Output.all(values)
    }

    /**
     * @param value Identifier for the managed rule.
     */
    @JvmName("pgrqncngycqefsnu")
    public suspend fun ruleId(`value`: Output<String>) {
        this.ruleId = value
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("kwkcigkrrwfvwnjr")
    public suspend fun action(`value`: Either<String, ActionType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("qciuajyrxcixyujr")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes the override action to be applied when rule matches.
     */
    @JvmName("kvvgbiextvpdhoau")
    public fun action(`value`: ActionType) {
        val toBeMapped = Either.ofRight<String, ActionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("vxyrlrvopsjwckdn")
    public suspend fun enabledState(`value`: Either<String, ManagedRuleEnabledState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("jbukewbwpopftdfs")
    public fun enabledState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ManagedRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes if the managed rule is in enabled or disabled state. Defaults to Disabled if not specified.
     */
    @JvmName("xqjthtaeqherbftk")
    public fun enabledState(`value`: ManagedRuleEnabledState) {
        val toBeMapped = Either.ofRight<String, ManagedRuleEnabledState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.enabledState = mapped
    }

    /**
     * @param value Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("dhunwfcvujsfuthl")
    public suspend fun exclusions(`value`: List<ManagedRuleExclusionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param argument Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("enfxoynqgmnemrmw")
    public suspend
    fun exclusions(argument: List<suspend ManagedRuleExclusionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ManagedRuleExclusionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.exclusions = mapped
    }

    /**
     * @param argument Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("ampemndqpirfhigm")
    public suspend fun exclusions(
        vararg
        argument: suspend ManagedRuleExclusionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ManagedRuleExclusionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.exclusions = mapped
    }

    /**
     * @param argument Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("cocgkambnuyxsnhx")
    public suspend fun exclusions(argument: suspend ManagedRuleExclusionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ManagedRuleExclusionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.exclusions = mapped
    }

    /**
     * @param values Describes the exclusions that are applied to this specific rule.
     */
    @JvmName("iqcfbptxhyqqkavu")
    public suspend fun exclusions(vararg values: ManagedRuleExclusionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.exclusions = mapped
    }

    /**
     * @param value Identifier for the managed rule.
     */
    @JvmName("wqcivqcosyupfnrj")
    public suspend fun ruleId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleId = mapped
    }

    internal fun build(): FrontDoorManagedRuleOverrideArgs = FrontDoorManagedRuleOverrideArgs(
        action = action,
        enabledState = enabledState,
        exclusions = exclusions,
        ruleId = ruleId ?: throw PulumiNullFieldException("ruleId"),
    )
}
